/*
 * Copyright (c) 2002-2016, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.util.signrequest.security;

import org.apache.log4j.Logger;

import java.io.UnsupportedEncodingException;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * Sha1HashService
 */
public class Sha1HashService implements HashService
{
    private static final String HEX_DIGITS = "0123456789abcdef";
    private static Logger _logger = Logger.getLogger( "lutece.security.signrequest" );

    /**
     * {@inheritDoc }
     */
    @Override
    public String getHash( String strSource )
    {
        MessageDigest md1 = null;

        try
        {
            md1 = MessageDigest.getInstance( "SHA-1" );
        }
        catch( NoSuchAlgorithmException e )
        {
            _logger.error( "Error creating hash " + e.getMessage( ), e );
        }

        try
        {
            md1.update( strSource.getBytes( "UTF-8" ) );
        }
        catch( UnsupportedEncodingException e )
        {
            _logger.error( "Error creating hash " + e.getMessage( ), e );
        }

        return hex( md1.digest( ) );
    }

    /**
     * Convert bytes into an hexadecimal string
     * 
     * @param bytes
     *            Array of bytes
     * @return An Hexadecimal string
     */
    private static String hex( byte [ ] bytes )
    {
        StringBuilder sb = new StringBuilder( bytes.length * 2 );

        for ( int i = 0; i < bytes.length; i++ )
        {
            int b = bytes [i] & 0xFF;
            sb.append( HEX_DIGITS.charAt( b >>> 4 ) ).append( HEX_DIGITS.charAt( b & 0xF ) );
        }

        return sb.toString( );
    }
}
